@@ -51,7 +51,7 @@ program initial_make
   real, parameter :: r_qv=-2.0e3   ! qv  rm εΥ
   real, parameter :: dRm=16.0/18.0  ! Rmax η (dr/dz)
   real, parameter :: rmax=50.0e3  ! ɽ̤Ǥ Rmax
-  real, parameter :: vmax=40.0  ! ɽ̤Ǥ Vmax
+  real, parameter :: vmax=50.0  ! ɽ̤Ǥ Vmax
   real, parameter :: z_v0=18.0e3  ! vmax ˤʤ (ɽ餳ޤ˸)
   real, parameter :: z_qv=18.0e3  ! qv ˤʤ
   real, parameter :: dr12=20.0e3  ! r1  r2 εΥ
@@ -61,8 +61,8 @@ program initial_make
   real, allocatable, dimension(:) :: rm2, vm2  ! ƹ٤Ǥκ® MWR
   real, parameter :: dRm2=128.0/18.0  ! Rmax η (dr/dz)
   real, parameter :: rmax2=100.0e3  ! ɽ̤Ǥ Rmax
-  real, parameter :: vmax2=35.0  ! ɽ̤Ǥ Vmax
-  real, parameter :: dr122=20.0e3  ! r1  r2 εΥ
+  real, parameter :: vmax2=50.0  ! ɽ̤Ǥ Vmax
+  real, parameter :: dr122=40.0e3  ! r1  r2 εΥ
   real, allocatable, dimension(:) :: r12, r22  ! inner, outer core boundary
   real, allocatable, dimension(:,:) :: x2  ! ɸѿ
 
@@ -243,15 +243,16 @@ write(*,*) "r12", r1(j), r2(j), r12(j), r22(j)
   end do
 
 !  call max_val_2d( N2, maxnx, maxny, max_val )  ! ͤŬѹ
-  max_val=1.5e-4
+!ORIG  max_val=1.5e-4
+  max_val=0.01
 
 !-- zd 
   zd=(/(((z_qv-z(j))/(z_qv-5.0e3)),j=1,nz)/)
 
   do j=1,nz
      do i=1,nr
-        qv(i,j)=max_val*func_a(zd(j))*(Bell( m_bell, x(i,j) )+0.5*Bell( m_bell, x2(i,j) ))
-        qv(i,j)=qv(i,j)*Cpd*theta0(i,j)/g
+        qv(i,j)=max_val*func_a(zd(j))*(2.5*Bell( m_bell, x(i,j) )+2.5*Bell( m_bell, x2(i,j) ))
+!ORIG        qv(i,j)=qv(i,j)*Cpd*theta0(i,j)/g
      end do
   end do
 
@@ -267,41 +268,51 @@ write(*,*) "r12", r1(j), r2(j), r12(j), r22(j)
 
 !-- ʲ netcdf 
   call HistoryCreate( file=trim(fname), title='SEQ initial data', &
-    & source='test', institution='test', dims=(/'r','z'/), dimsizes=(/nr,nz/),  &
-    & longnames=(/'r-coordinate','z-coordinate'/),  &
-    & units=(/'m','m'/), origin=0.0, interval=0.0 )
+!ORIG    & source='test', institution='test', dims=(/'r','z'/), dimsizes=(/nr,nz/),  &
+    & source='test', institution='test', dims=(/'r','z', 't'/), dimsizes=(/nr,nz,0/),  &
+    & longnames=(/'r-coordinate','z-coordinate','t-coordinate'/),  &
+!ORIG    & longnames=(/'r-coordinate','z-coordinate'/),  &
+!ORIG    & units=(/'m','m'/), origin=0.0, interval=0.0 )
+    & units=(/'m','m','s'/), origin=0.0, interval=10.0 )
 
   call HistoryPut( 'r', r )
   call HistoryPut( 'z', z )
 
-  call HistoryAddVariable( varname='v', dims=(/'r','z'/), &
+  call HistoryAddVariable( varname='v', dims=(/'r','z','t'/), &
+!ORIG  call HistoryAddVariable( varname='v', dims=(/'r','z'/), &
     & longname='tangential wind', units='m/s', xtype='float')
 
+  call HistoryAddVariable( varname='pres', dims=(/'r','z','t'/), &
+!ORIG  call HistoryAddVariable( varname='pres', dims=(/'r','z'/), &
+    & longname='pressure', units='Pa', xtype='float')
+
+  call HistoryAddVariable( varname='theta', dims=(/'r','z','t'/), &
+!ORIG  call HistoryAddVariable( varname='theta', dims=(/'r','z'/), &
+    & longname='potential temperature', units='K', xtype='float')
+
+!ORIG  call HistoryAddVariable( varname='rho', dims=(/'r','z'/), &
+  call HistoryAddVariable( varname='rho', dims=(/'r','z','t'/), &
+    & longname='density', units='kg/m3', xtype='float')
+
+!ORIG  call HistoryAddVariable( varname='Q', dims=(/'r','z'/), &
+  call HistoryAddVariable( varname='Q', dims=(/'r','z','t'/), &
+    & longname='heating rate', units='K/s', xtype='float')
+!ORIG    & longname='heating rate', units='J/s', xtype='float')
+
+!ORIG  call HistoryAddVariable( varname='mom', dims=(/'r','z'/), &
+  call HistoryAddVariable( varname='mom', dims=(/'r','z','t'/), &
+    & longname='momentum source rate', units='m/s2', xtype='float')
+
   call HistoryPut( 'v',v0 )
 
-  call HistoryAddVariable( varname='pres', dims=(/'r','z'/), &
-    & longname='pressure', units='Pa', xtype='float')
-
   call HistoryPut( 'pres',pres )
 
-  call HistoryAddVariable( varname='theta', dims=(/'r','z'/), &
-    & longname='potential temperature', units='K', xtype='float')
-
   call HistoryPut( 'theta', theta0 )
 
-  call HistoryAddVariable( varname='rho', dims=(/'r','z'/), &
-    & longname='density', units='kg/m3', xtype='float')
-
   call HistoryPut( 'rho', rho )
 
-  call HistoryAddVariable( varname='Q', dims=(/'r','z'/), &
-    & longname='heating rate', units='J/s', xtype='float')
-
   call HistoryPut( 'Q', qv )
 
-  call HistoryAddVariable( varname='mom', dims=(/'r','z'/), &
-    & longname='momentum source rate', units='m/s2', xtype='float')
-
   call HistoryPut( 'mom', mom )
 
   call HistoryClose
