@@ -10,6 +10,11 @@ program draw
 
   implicit none
 
+  integer, parameter :: IWS=1
+  integer, dimension(1), parameter :: lidx=(/5/), ltyp=(/1/)
+  integer, dimension(1), parameter :: pidx=(/9/), ptyp=(/11/)
+  real, dimension(1), parameter :: psiz=(/0.06/)
+
   integer :: i, j, k
   integer :: nx, ny, nl
   integer :: nargv, fig_type
@@ -68,8 +73,8 @@ program draw
   call HistoryGet( trim(fname), trim(x_axis), x(1:nx) )
   call HistoryGet( trim(fname), trim(y_axis), y(1:ny) )
 
-  forma=trim(x_axis)//'=^1:'  &
-  &   //trim(adjustl( i2c_convert( nx ) ))//','//trim(y_axis)//'=^1:'  &
+  forma=trim(x_axis)//'=^1:^'  &
+  &   //trim(adjustl( i2c_convert( nx ) ))//','//trim(y_axis)//'=^1:^'  &
   &   //trim(adjustl( i2c_convert( ny ) ))
   
 
@@ -153,7 +158,7 @@ program draw
 write(*,*) "draw", trim(draw_title)
   call color_setting( 10, (/smin, smax/), min_tab=10999, max_tab=99999 )  
 
-  call DclOpenGraphics(2)
+  call DclOpenGraphics(IWS)
 
   if(fig_type==1)then
      if(txtname/='')then
@@ -239,14 +244,18 @@ write(*,*) "draw", trim(draw_title)
      end if
 
      do i=ydmin,ydmax
-        call Dcl_PL( trim(line_flag), trim(draw_title),  &
+        call Dcl_PL( trim(line_flag),  &
+  &          trim(draw_title)//'_('//trim(adjustl(y_axis))//'='  &
+  &          //trim(adjustl(r2c_convert(y(i),forma='(1PE10.2)')))//')"',  &
   &          xd(xdmin:xdmax,i:i),  &
   &          val1(xdmin:xdmax,i:i),  &
   &          xd(xdmin:xdmax,i:i),  &
   &          val2(xdmin:xdmax,i:i),  &
   &          (/trim(x_axis), '               '/),  &
   &          x_int=(/xd(xdmin,1), xd(xdmax,1)/), y_int=(/cmin, cmax/),  &
-  &          viewx_int=(/0.2, 0.8/), viewy_int=(/0.2, 0.8/) )
+  &          viewx_int=(/0.2, 0.8/), viewy_int=(/0.2, 0.8/),  &
+  &          l_idx=(/lidx/), l_typ=(/ltyp/), p_idx=(/pidx/),  &
+  &          p_typ=(/ptyp/), p_siz=(/psiz/) )
      end do
   end if
 
@@ -274,14 +283,18 @@ write(*,*) "draw", trim(draw_title)
      end if
 
      do i=xdmin,xdmax
-        call Dcl_PL( trim(line_flag), trim(draw_title),  &
+        call Dcl_PL( trim(line_flag),  &
+  &          trim(draw_title)//'_('//trim(adjustl(x_axis))//'='  &
+  &          //trim(adjustl(r2c_convert(x(i),forma='(1PE10.2)')))//')"',  &
   &          dum1(i:i,ydmin:ydmax),  &
   &          yd(ydmin:ydmax,i:i),  &
   &          dum2(i:i,ydmin:ydmax),  &
   &          yd(ydmin:ydmax,i:i),  &
   &          (/'               ', trim(y_axis)/),  &
   &          x_int=(/yd(ydmin,1), yd(ydmax,1)/), y_int=(/cmin, cmax/),  &
-  &          viewx_int=(/0.2, 0.8/), viewy_int=(/0.2, 0.8/) )
+  &          viewx_int=(/0.2, 0.8/), viewy_int=(/0.2, 0.8/),  &
+  &          l_idx=(/lidx/), l_typ=(/ltyp/), p_idx=(/pidx/),  &
+  &          p_typ=(/ptyp/), p_siz=(/psiz/) )
      end do
   end if
 
