@@ -70,7 +70,7 @@ program sound_1d
 !-- namelist file ɤ߹
 
   namelist /input /z_ref, p_ref, list_name, dmp_flag, undef, draw_flag,  &
-  &                draw_region_p, draw_region_z, IWS, refer_flag, unit_v,  &
+  &                draw_region_p, draw_region_z, IWS, unit_v,  &
   &                sysfont
   read(5,nml=input)
 
@@ -127,7 +127,7 @@ program sound_1d
   if(no_draw_flag.eqv..false.)then
      if(len_trim(adjustl(sysfont))/=0)then
         call SGISET( 'IFONT', 1 )
-        call SWLSET( 'SYSFONT', .true. )
+        call SWLSET( 'LSYSFNT', .true. )
         write(*,*) "This drawing mode is sysfont."
      else
         call SGISET( 'IFONT', 2 )
