@@ -123,7 +123,7 @@ program sound_2d
 !-- DCL set
   if(len_trim(adjustl(sysfont))/=0)then
      call SGISET( 'IFONT', 1 )
-     call SWLSET( 'SYSFONT', .true. )
+     call SWLSET( 'LSYSFNT', .true. )
      write(*,*) "This drawing mode is sysfont."
   else
      call SGISET( 'IFONT', 2 )
