@@ -26,8 +26,8 @@ program cov
      y(i)=c2r_convert( cval(2,i) )
   end do
 
-  call Cor_Coe( x, y, cc )
-  call Reg_Line( x, y, slope, intercept )
+  call Cor_Coe_1d( x, y, cc )
+  call Reg_Line_1d( x, y, slope, intercept )
   call Mean_1d( x, xmean )
   call Mean_1d( y, ymean )
 !  call Anomaly_1d( nx, x, xa )
