@@ -25,7 +25,9 @@ program thermo  ! thermo طδؿǧ
   tmpv=es_TD(es,dl)
   tmpv=LH(temp,dl)
   tmpv=eP_2_qv(es,pres,dl)
+  tmpv=eP_2_sh(es,pres,dl)
   tmpv=TP_2_qvs(temp,pres,dl)
+  tmpv=TP_2_shs(temp,pres,dl)
   tmpv=qvP_2_e(qv,pres,dl)
   tmpv=theta_dry(temp,pres,dl)
   tmpv=theta_moist(temp,pres,qv,dl)
