@@ -70,7 +70,7 @@ subroutine rand_make(L,output)
   integer, intent(in) :: L  ! Ϥ + 1 ο
   integer, intent(inout) :: output  ! Ϥ
   integer :: a, b, x0, i, input
-  integer, intrinsic :: time
+  integer, external :: time
 
   input=time()
   input=mod(input,L)
@@ -98,7 +98,7 @@ subroutine multi_rand_make(L,n,interval,output)
   integer, intent(in) :: interval  ! μδֳ
   integer, intent(inout) :: output(n)  ! Ϥ
   integer :: a, b, x0, i, j, input, itmp
-  integer, intrinsic :: time
+  integer, external :: time
 
   itmp=0
 
