@@ -103,7 +103,7 @@ real function term_v_warm( rhob, qr, rho0 )
   real, intent(in) :: qr
   real, intent(in) :: rho0
 
-  term_v_warm=36.34*(rho0/rhob)*(rhob*qr)**0.1346
+  term_v_warm=36.34*(rho0/rhob)*((rhob*qr)**0.1346)
 
   return
 
