@@ -6,11 +6,11 @@ module Thermo_Function  ! Ǯϳؤ˴طؿ
   ! Ǯϳѿ֤Ѵؿξ, "..2.."Ȥˤʤ.
   ! ξ, 2 ƤΤ 2 θˤΤѴȤ
   ! Ȥ̣Ƥ.
-use Thermo_Const
-use Phys_Const
-use stdio
-use Algebra
-use Statistics
+  use Thermo_Const
+  use Phys_Const
+  use stdio
+  use Algebra
+  use Statistics
 
 contains
 
@@ -19,7 +19,7 @@ real function tetens( T, dl )  ! ƥƥμ¸Ѥ˰¿׻.
   implicit none
   real, intent(in) :: T  ! 絤β [K]
   integer, intent(in), optional :: dl  ! ǥХå٥
-  real, parameter :: a=7.5, b=237.7, c=9.5, d=265.5
+  real, parameter :: a=7.5, b=237.3, c=9.5, d=265.5
 
   if(t<=t0)then
      tetens=e0*10.0**(c*(t-t0)/(t-t0+d))
@@ -109,11 +109,12 @@ real function es_TD(e, dl)  ! es_Bolton Ѥ˰¿η׻εջ
   real, intent(in) :: e  ! 絤ο [Pa]
   integer, intent(in), optional :: dl  ! ǥХå٥
   real, parameter :: a=17.67, c=29.65
+  real, parameter :: emin=1.0e-3
 
   if(e>0.0)then
      es_TD=c+(a*(t0-c))/(a-log(e/e0))
   else
-     es_TD=t0  ! true ??
+     es_TD=c+(a*(t0-c))/(a-log(emin/e0))
   end if
 
   if(present(dl))then
@@ -171,20 +172,38 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
-real function TP_2_qvs(T,P, dl)  ! ٤˰º׻
-  ! Ǥ, es_Bolton Ѥ˰¿׻,
+real function TP_2_qvs(T,P, opt, dl)  ! ٤˰º׻
+  ! Ǥ, ˰¿׻,
   ! eP_2_qv ѤƺѴ뤳Ȥ˰º׻.
   use Thermo_Const
   implicit none
   real, intent(in) :: T  !  [K]
   real, intent(in) :: P  ! 絤 [Pa]
+  character(1), intent(in), optional :: opt  ! 'b' = Bolton, 't' = Tetens.
+                                             ! default = Bolton
   integer, intent(in), optional :: dl  ! ǥХå٥
   real :: eps
   real :: es
 
   eps=Rd/Rv
-  es=es_Bolton(T)
-  TP_2_qvs=eps*es/(P-es)
+
+  if(present(opt))then
+     select case (opt(1:1))
+     case ('b')
+        es=es_Bolton(T)
+     case ('t')
+        es=tetens(T)
+     end select
+  else
+     es=es_Bolton(T)
+  end if
+
+  if(P<es)then
+     TP_2_qvs=10.0
+     write(*,*) "*** WARNING (TP_2_qvs:thermo_function) : es exceeds P.", P, es
+  else
+     TP_2_qvs=eps*es/(P-es)
+  end if
 
   if(present(dl))then
      call debug_flag_r( dl, 'Thermo_Function', 'TP_2_qvs', TP_2_qvs, 'kg kg-1' )
@@ -196,6 +215,65 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
+real function eP_2_sh(e,P, dl)  ! 漾׻
+  use Thermo_Const
+  implicit none
+  real, intent(in) :: e  !  [Pa]
+  real, intent(in) :: P  ! 絤 [Pa]
+  integer, intent(in), optional :: dl  ! ǥХå٥
+  real :: eps
+
+  eps=Rd/Rv
+  eP_2_sh=eps*e/P
+
+  if(present(dl))then
+     call debug_flag_r( dl, 'Thermo_Function', 'eP_2_sh', eP_2_sh, 'kg kg-1' )
+  end if
+
+  return
+end function
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
+real function TP_2_shs(T,P, opt, dl)  ! ٤˰漾׻
+  ! Ǥ, ˰¿׻,
+  ! eP_2_sh ѤƺѴ뤳Ȥ˰漾׻.
+  use Thermo_Const
+  implicit none
+  real, intent(in) :: T  !  [K]
+  real, intent(in) :: P  ! 絤 [Pa]
+  character(1), intent(in), optional :: opt  ! 'b' = Bolton, 't' = Tetens.
+                                             ! default = Bolton
+  integer, intent(in), optional :: dl  ! ǥХå٥
+  real :: eps
+  real :: es
+
+  eps=Rd/Rv
+
+  if(present(opt))then
+     select case (opt(1:1))
+     case ('b')
+        es=es_Bolton(T)
+     case ('t')
+        es=tetens(T)
+     end select
+  else
+     es=es_Bolton(T)
+  end if
+
+  TP_2_shs=eps*es/P
+
+  if(present(dl))then
+     call debug_flag_r( dl, 'Thermo_Function', 'TP_2_shs', TP_2_shs, 'kg kg-1' )
+  end if
+
+  return
+end function
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
 real function qvP_2_e(qv,P, dl)  ! ׻
   use Thermo_Const
   implicit none
@@ -319,6 +397,7 @@ real function TqvP_2_TLCL(T,qv,P, dl)  !! ٤Ⱥ T_LCL ׻
   real, intent(in) :: P  !  [Pa]
   integer, intent(in), optional :: dl  ! ǥХå٥
   real, parameter :: coe=2840.0, a=3.5, b=4.805, c=55.0
+  real, parameter :: emin=1.0e-3
   real :: e
 
   e=qvP_2_e(qv,P)
@@ -326,7 +405,7 @@ real function TqvP_2_TLCL(T,qv,P, dl)  !! ٤Ⱥ T_LCL ׻
   if(e>0.0)then
      TqvP_2_TLCL=coe/(a*log(T)-log(e)-b)+55.0
   else
-     TqvP_2_TLCL=coe/(a*log(T)-b)+55.0  ! true ??
+     TqvP_2_TLCL=coe/(a*log(T)-log(emin)-b)+55.0
   end if
 
   if(present(dl))then
@@ -354,6 +433,10 @@ real function thetae_Bolton(T,qv,P, dl)
 
   T_LCL=TqvP_2_TLCL(T,qv,P)
   qvs=TP_2_qvs(T_LCL,P)
+  if(qvs>1.0)then
+     qvs=TP_2_shs(T_LCL,P)
+  end if
+
   thetae_Bolton=T*((p0/P)**(a*(1.0-b*qvs)))  &
    &            *exp((c/T_LCL-2.54)*qvs*(1.0+d*qvs))
 
@@ -377,6 +460,10 @@ real function thetaes_Bolton(T,P, dl)  ! Bolton(1980) ˤˡѤ˰̤׻.
   real, parameter :: a=0.2854, b=0.28, c=3376.0, d=0.81
 
   qvs=TP_2_qvs(T,P)
+  if(qvs>1.0)then
+     qvs=TP_2_shs(T,P)
+  end if
+
   thetaes_Bolton=T*((p0/P)**(a*(1.0-b*qvs)))  &
    &            *exp((c/T-2.54)*qvs*(1.0+d*qvs))
 
@@ -390,22 +477,35 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
-real function TqvP_2_thetae(T,qv,P, dl)  ! , , ̤׻.
+real function TqvP_2_thetae(T,qv,P, opt, dl)  ! , , ̤׻.
   ! T_LCL ѤΤ, ΤδؿѤ.
   use Thermo_Const
   implicit none
   real, intent(in) :: T  !  [K]
   real, intent(in) :: qv  !  [kg / kg]
   real, intent(in) :: P  !  [Pa]
+  character(1), intent(in), optional :: opt  ! 'b' = Bolton, 't' = Tetens.
+                                             ! default = Bolton
   integer, intent(in), optional :: dl  ! ǥХå٥
   real :: T_LCL, kappa, theta_d, e, qvs
+  character(1) :: mopt
   real, parameter :: a=0.2854, b=0.28, c=3376.0, d=0.81
 
+  if(present(opt))then
+     mopt=opt
+  else
+     mopt='b'
+  end if
+
   kappa=Rd/Cpd
   e=qvP_2_e(qv,P)
   T_LCL=TqvP_2_TLCL(T,qv,P)
   theta_d=T*(p0/(P-e))**kappa
-  qvs=TP_2_qvs(T_LCL,P)
+  qvs=TP_2_qvs(T_LCL,P,mopt)
+  if(qvs>1.0)then
+     qvs=TP_2_shs(T_LCL,P,mopt)
+  end if
+
   TqvP_2_thetae=theta_d*exp(LH(T_LCL)*qvs/(Cpd*T_LCL))
 
   if(present(dl))then
@@ -418,22 +518,35 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
-real function TqvP_2_thetaes(T,P, dl)  ! , , ˰̤׻.
+real function TqvP_2_thetaes(T,P, opt, dl)  ! , , ˰̤׻.
   ! T_LCL ѤΤ, ΤδؿѤ.
   use Thermo_Const
   implicit none
   real, intent(in) :: T  !  [K]
 !  real, intent(in) :: qv  !  [kg / kg]
   real, intent(in) :: P  !  [Pa]
+  character(1), intent(in), optional :: opt  ! 'b' = Bolton, 't' = Tetens.
+                                             ! default = Bolton
   integer, intent(in), optional :: dl  ! ǥХå٥
   real :: kappa, theta_d, qvs !,e
+  character(1) :: mopt
   real, parameter :: a=0.2854, b=0.28, c=3376.0, d=0.81
 
+  if(present(opt))then
+     mopt=opt
+  else
+     mopt='b'
+  end if
+
   kappa=Rd/Cpd
 !  e=qvP_2_e(qv,P)
 !  theta_d=T*(p0/(P-e))**kappa
   theta_d=T*(p0/P)**kappa
-  qvs=TP_2_qvs(T,P)
+  qvs=TP_2_qvs(T,P,mopt)
+  if(qvs>1.0)then
+     qvs=TP_2_shs(T,P,mopt)
+  end if
+
   TqvP_2_thetaes=theta_d*exp(LH(T)*qvs/(Cpd*T))
 
   if(present(dl))then
@@ -446,16 +559,28 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
-real function RHT_2_e(RH,T, dl)  ! м٤Ȳ٤׻
+real function RHT_2_e(RH,T, opt, dl)  ! м٤Ȳ٤׻
   ! $RH=(e/es)\times 100$ Ȥ׻.
   use Thermo_Const
   implicit none
   real, intent(in) :: RH  ! м [%]
   real, intent(in) :: T  !  [K]
+  character(1), intent(in), optional :: opt  ! 'b' = Bolton, 't' = Tetens.
+                                             ! default = Bolton
   integer, intent(in), optional :: dl  ! ǥХå٥
   real :: es
 
-  es=es_Bolton(T)
+  if(present(opt))then
+     select case (opt(1:1))
+     case ('b')
+        es=es_Bolton(T)
+     case ('t')
+        es=tetens(T)
+     end select
+  else
+     es=es_Bolton(T)
+  end if
+
   RHT_2_e=RH*es*1.0e-2
 
   if(present(dl))then
@@ -468,16 +593,28 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
-real function eT_2_RH(e,T, dl)  ! Ȳ٤м٤׻
+real function eT_2_RH(e,T, opt, dl)  ! Ȳ٤м٤׻
   ! $RH=(e/es)\times 100$ Ȥ׻.
   use Thermo_Const
   implicit none
   real, intent(in) :: e  !  [Pa]
   real, intent(in) :: T  !  [K]
+  character(1), intent(in), optional :: opt  ! 'b' = Bolton, 't' = Tetens.
+                                             ! default = Bolton
   integer, intent(in), optional :: dl  ! ǥХå٥
   real :: es
 
-  es=es_Bolton(T)
+  if(present(opt))then
+     select case (opt(1:1))
+     case ('b')
+        es=es_Bolton(T)
+     case ('t')
+        es=tetens(T)
+     end select
+  else
+     es=es_Bolton(T)
+  end if
+
   eT_2_RH=100.0*e/es
 
   if(present(dl))then
@@ -490,17 +627,26 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
-real function RHTP_2_qv(RH,T,P, dl)  ! м٤Ȳ٤麮׻
+real function RHTP_2_qv(RH,T,P, opt, dl)  ! м٤Ȳ٤麮׻
   ! RHT_2_e ׻, eP_2_qv 麮׻.
   use Thermo_Const
   implicit none
   real, intent(in) :: RH  ! м [%]
   real, intent(in) :: T  !  [K]
   real, intent(in) :: P  !  [Pa]
+  character(1), intent(in), optional :: opt  ! 'b' = Bolton, 't' = Tetens.
+                                             ! default = Bolton
   integer, intent(in), optional :: dl  ! ǥХå٥
   real :: e
+  character(1) :: mopt
 
-  e=RHT_2_e(RH,T)
+  if(present(opt))then
+     mopt=opt
+  else
+     mopt='b'
+  end if
+
+  e=RHT_2_e(RH,T,mopt)
   RHTP_2_qv=eP_2_qv(e,P)
 
   if(present(dl))then
@@ -513,18 +659,27 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
-real function qvTP_2_RH(qv,T,P, dl)  ! Ȳ٤м٤׻.
+real function qvTP_2_RH(qv,T,P, opt, dl)  ! Ȳ٤м٤׻.
   ! qvP_2_e ׻, м٤Ѥ.
   use Thermo_Const
   implicit none
   real, intent(in) :: qv  ! м [kg / kg]
   real, intent(in) :: T  !  [K]
   real, intent(in) :: P  !  [Pa]
+  character(1), intent(in), optional :: opt  ! 'b' = Bolton, 't' = Tetens.
+                                             ! default = Bolton
   integer, intent(in), optional :: dl  ! ǥХå٥
   real :: e
+  character(1) :: mopt
+
+  if(present(opt))then
+     mopt=opt
+  else
+     mopt='b'
+  end if
 
   e=qvP_2_e(qv,P)
-  qvTP_2_RH=eT_2_RH(e,T)
+  qvTP_2_RH=eT_2_RH(e,T,mopt)
 
   if(present(dl))then
      call debug_flag_r( dl, 'Thermo_Function', 'qvTP_2_RH', qvTP_2_RH, '%' )
@@ -1609,6 +1764,322 @@ end function rho_ocean
 !-----------------------------------------------------
 !-----------------------------------------------------
 
+real function PTS_2_theta( pres, temp, sal, dl )
+! Vallis (2006)  (1.153) Ѥ, β٤򲹰 [degC] Ѵ.
+! theta = T exp(f),
+! f(p,T,S) = - k*(1+gams*p/2+b*(T-to0))
+! k = a0 * bt * p / cpo = 1.67 * pres * 10^(-4+5-3-3) / 1.027 / 3.986 / alph,
+! b = bts / bt = 0.1 / 1.67
+! cpo = cpo0 * (1 + bss * (S-so0) ) = 3.986e3 * alph
+  implicit none
+  real, intent(in) :: pres    !  [Bar ~ x10 m]
+  real, intent(in) :: temp    !  [degC]
+  real, intent(in) :: sal     ! ʬǻ [PSU]
+  integer, intent(in), optional :: dl  ! ǥХå٥
+
+  real :: a0=9.738e-4    ! [m3 kg-1]
+  real :: to0=283.0      ! [K]
+  real :: so0=35.0       ! [psu]
+  real :: bt=1.67e-4     ! [K-1]
+  real :: bts=1.0e-5     ! [K-2]
+  real :: bs=7.8e-4      ! [psu-1]
+  real :: bss=1.5e-3     ! [psu-1]
+  real :: cpo0=3986.0    ! [J K-1 kg-1]
+  real :: gams=1.1e-3    ! [Bar-1]
+
+  real :: k, b, alph, f, TK
+
+  TK=temp+t0
+  b=0.1/1.67
+  alph=1.0+bss*(sal-so0)
+  k=1.67e-5*pres/(1.027*3.986*alph)
+  f=-k*(1.0+0.5*gams*pres+b*(TK-to0))
+
+  PTS_2_theta=TK*exp(f)-t0
+
+  if(present(dl))then
+     call debug_flag_r( dl, 'Thermo_Function', 'PTS_2_theta', PTS_2_theta, 'degC' )
+  end if
+
+end function PTS_2_theta
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
+real function D26( pres, temp, undef, dep_thres, temp_thres, neg, dl )
+! Lin et al. (2008) Ѥ, 26 ٿ٤׻.
+! ֤ͤ m (dBar) ñ̤֤.
+  implicit none
+  real, intent(in) :: pres(:)             !  [dBar]
+  real, intent(in) :: temp(size(pres))    !  [degC]
+  real, intent(in), optional :: undef     ! ̤
+  real, intent(in), optional :: dep_thres ! ׻оݤȤǡϿ.
+                                          ! ǥե = Ǿؤ.
+  real, intent(in), optional :: temp_thres! ׻оݤȤǡϲ.
+                                          ! ǥե = 26.0 degC .
+  logical, intent(in), optional :: neg    ! d26 ޤǤ 26 degC ʲ
+                                          ! ʤäƤޤؤΰ.
+                                          ! .true. = ؤʬ׻ʤ.
+                                          ! .false. = ؤʬ׻.
+                                          ! default = .true.
+                                          ! .false. ξ, OHC < 0 Ȥʤ
+                                          ! ǽ⤢.
+  integer, intent(in), optional :: dl  ! ǥХå٥
+
+  integer :: i, j, nz
+  real :: dtop, dthres, TOHC
+  real, dimension(size(pres)) :: ttemp
+  logical :: neg_flag
+
+  nz=size(pres)
+
+  if(present(dep_thres))then
+     dthres=dep_thres
+  else
+     dthres=0.0
+  end if
+
+  if(present(temp_thres))then
+     TOHC=temp_thres
+  else
+     TOHC=26.0
+  end if
+
+  if(present(neg))then
+     neg_flag=neg
+  else
+     neg_flag=.true.
+  end if
+
+  if(present(undef))then
+
+     !-- determining dtop
+     do i=1,nz
+        if(temp(i)/=undef)then
+           dtop=pres(i)
+           exit
+        end if
+     end do
+     if(dthres/=0.0.and.dtop>=dthres)then
+        D26=undef
+        return
+     end if
+
+     !-- determining d26
+     do i=nz,2,-1
+        if(temp(i)/=undef.and.temp(i-1)/=undef.and.  &
+  &        temp(i)<=TOHC.and.temp(i-1)>=TOHC)then
+           D26=pres(i-1)
+           exit
+        end if
+     end do
+     if(temp(nz)>=TOHC.and.temp(nz)/=undef)then
+        D26=pres(nz)
+     end if
+
+     if(D26<=dtop)then
+        D26=undef
+        return
+     end if
+
+  else
+
+     !-- determining dtop
+     dtop=pres(1)
+     if(dthres/=0.0.and.dtop>=dthres)then
+        D26=0.0
+        return
+     end if
+
+     !-- determining d26
+     do i=nz,2,-1
+        if(temp(i)<=TOHC.and.temp(i-1)>=TOHC)then
+           D26=pres(i-1)
+           exit
+        end if
+     end do
+     if(temp(nz)>=TOHC)then
+        D26=pres(nz)
+     end if
+
+     !-- calculating delta T
+     do i=1,nz
+        ttemp(i)=temp(i)-TOHC
+        if(neg_flag.eqv..true.)then
+           if(ttemp(i)<0.0)then
+              ttemp(i)=0.0
+           end if
+        end if
+     end do
+
+     if(d26<=dtop)then
+        D26=0.0
+        return
+     end if
+
+  end if
+
+  if(present(dl))then
+     call debug_flag_r( dl, 'Thermo_Function', 'D26', D26, 'm (dBar)' )
+  end if
+
+  return
+end function D26
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
+real function OHC( pres, temp, undef, dep_thres, temp_thres, neg, dl )
+! Lin et al. (2008) Ѥ, Ǯ̤׻.
+! ֤ͤ kJ/cm2 ñ̤֤.
+  implicit none
+  real, intent(in) :: pres(:)             !  [dBar]
+  real, intent(in) :: temp(size(pres))    !  [degC]
+  real, intent(in), optional :: undef     ! ̤
+  real, intent(in), optional :: dep_thres ! ׻оݤȤǡϿ.
+                                          ! ǥե = Ǿؤ.
+  real, intent(in), optional :: temp_thres! ׻оݤȤǡϲ.
+                                          ! ǥե = 26.0 degC .
+  logical, intent(in), optional :: neg    ! d26 ޤǤ 26 degC ʲ
+                                          ! ʤäƤޤؤΰ.
+                                          ! .true. = ؤʬ׻ʤ.
+                                          ! .false. = ؤʬ׻.
+                                          ! default = .true.
+                                          ! .false. ξ, OHC < 0 Ȥʤ
+                                          ! ǽ⤢.
+  integer, intent(in), optional :: dl  ! ǥХå٥
+
+  real, parameter :: Cpsea=4178.0
+  real, parameter :: rhocu=1026.0
+  integer :: i, j, nz
+  real :: d26, dtop, dthres, TOHC
+  real, dimension(size(pres)) :: ttemp
+  logical :: neg_flag
+
+  nz=size(pres)
+
+  if(present(dep_thres))then
+     dthres=dep_thres
+  else
+     dthres=0.0
+  end if
+
+  if(present(temp_thres))then
+     TOHC=temp_thres
+  else
+     TOHC=26.0
+  end if
+
+  if(present(neg))then
+     neg_flag=neg
+  else
+     neg_flag=.true.
+  end if
+
+  if(present(undef))then
+
+     !-- determining dtop
+     do i=1,nz
+        if(temp(i)/=undef)then
+           dtop=pres(i)
+           exit
+        end if
+     end do
+     if(dthres/=0.0.and.dtop>=dthres)then
+        OHC=undef
+        return
+     end if
+
+     !-- determining d26
+     do i=nz,2,-1
+        if(temp(i)/=undef.and.temp(i-1)/=undef.and.  &
+  &        temp(i)<=TOHC.and.temp(i-1)>=TOHC)then
+           d26=pres(i-1)
+           exit
+        end if
+     end do
+     if(temp(nz)>=TOHC.and.temp(nz)/=undef)then
+        d26=pres(nz)
+     end if
+
+     !-- calculating delta T
+     do i=1,nz
+        if(temp(i)/=undef)then
+           ttemp(i)=temp(i)-TOHC
+           if(neg_flag.eqv..true.)then
+              if(ttemp(i)<0.0)then
+                 ttemp(i)=0.0
+              end if
+           end if
+        end if
+     end do
+
+     if(d26<=dtop)then
+        OHC=undef
+        return
+     end if
+
+     !-- calculating integration
+     call rectangle_int( pres(1:nz), ttemp(1:nz), dtop, d26, OHC, undeff=undef )
+
+     !-- adjusting unit
+     if(OHC/=undef)then
+        OHC=OHC*Cpsea*rhocu*1.0e-7
+     end if
+
+  else
+
+     !-- determining dtop
+     dtop=pres(1)
+     if(dthres/=0.0.and.dtop>=dthres)then
+        OHC=0.0
+        return
+     end if
+
+     !-- determining d26
+     do i=nz,2,-1
+        if(temp(i)<=TOHC.and.temp(i-1)>=TOHC)then
+           d26=pres(i-1)
+           exit
+        end if
+     end do
+     if(temp(nz)>=TOHC)then
+        d26=pres(nz)
+     end if
+
+     !-- calculating delta T
+     do i=1,nz
+        ttemp(i)=temp(i)-TOHC
+        if(neg_flag.eqv..true.)then
+           if(ttemp(i)<0.0)then
+              ttemp(i)=0.0
+           end if
+        end if
+     end do
+
+     if(d26<=dtop)then
+        OHC=0.0
+        return
+     end if
+
+     !-- calculating integration
+     call rectangle_int( pres(1:nz), ttemp(1:nz), dtop, d26, OHC )
+
+     !-- adjusting unit
+     OHC=OHC*Cpsea*rhocu*1.0e-7
+
+  end if
+
+  if(present(dl))then
+     call debug_flag_r( dl, 'Thermo_Function', 'OHC', OHC, 'kJ cm-2' )
+  end if
+
+  return
+end function OHC
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
 !real function
 
 
