@@ -4,6 +4,7 @@
 
 module Trajectory
 !  ȥ饸ȥϤԤ롼
+  use Basis
   use Statistics
 
   public :: Forward_Traject_2d
@@ -48,7 +49,6 @@ subroutine Forward_Traject_2d( dt, stime, step, ini_x, ini_y,  &
                                              ! ǥեȤ false (ɽ)
   character(3) :: option
   integer :: nx, ny, nt, nc, i, j, k, i_trajt
-  integer :: defun_i
   real :: inter_u(size(x),size(y)), inter_v(size(x),size(y))
   real :: trajt(step)
   real :: defun
@@ -90,10 +90,8 @@ subroutine Forward_Traject_2d( dt, stime, step, ini_x, ini_y,  &
 
   if(present(undef))then
      defun=undef
-     defun_i=int(undef)
   else
-     defun_i=-2147483648
-     defun=real(defun_i)
+     defun=-999.0
   end if
 
   do j=1,nc
@@ -251,7 +249,6 @@ subroutine Forward_Traject_3d( dt, stime, step, ini_x, ini_y, ini_z,  &
                                              ! ǥեȤ false (ɽ)
   character(3) :: option
   integer :: nx, ny, nz, nt, nc, i, j, k, l, i_trajt
-  integer :: defun_i
   real :: inter_u(size(x),size(y),size(z))
   real :: inter_v(size(x),size(y),size(z))
   real :: inter_w(size(x),size(y),size(z))
@@ -298,10 +295,8 @@ subroutine Forward_Traject_3d( dt, stime, step, ini_x, ini_y, ini_z,  &
 
   if(present(undef))then
      defun=undef
-     defun_i=int(undef)
   else
-     defun_i=-2147483648
-     defun=real(defun_i)
+     defun=-999.0
   end if
 
   do j=1,nc
@@ -478,7 +473,6 @@ subroutine Backward_Traject_2d( dt, stime, step, ini_x, ini_y,  &
                                              ! ǥեȤ false (ɽ)
   character(3) :: option
   integer :: nx, ny, nt, nc, i, j, k, i_trajt, ri_trajt
-  integer :: defun_i
   real :: inter_u(size(x),size(y)), inter_v(size(x),size(y))
   real :: trajt(step), r_t(size(t))
   real :: defun
@@ -524,10 +518,8 @@ subroutine Backward_Traject_2d( dt, stime, step, ini_x, ini_y,  &
 
   if(present(undef))then
      defun=undef
-     defun_i=int(undef)
   else
-     defun_i=-2147483648
-     defun=real(defun_i)
+     defun=-999.0
   end if
 
   do j=1,nc
@@ -697,7 +689,6 @@ subroutine Backward_Traject_3d( dt, stime, step, ini_x, ini_y, ini_z,  &
                                              ! ǥեȤ false (ɽ)
   character(3) :: option
   integer :: nx, ny, nz, nt, nc, i, j, k, l, i_trajt, ri_trajt
-  integer :: defun_i
   real :: inter_u(size(x),size(y),size(z))
   real :: inter_v(size(x),size(y),size(z))
   real :: inter_w(size(x),size(y),size(z))
@@ -748,10 +739,8 @@ subroutine Backward_Traject_3d( dt, stime, step, ini_x, ini_y, ini_z,  &
 
   if(present(undef))then
      defun=undef
-     defun_i=int(undef)
   else
-     defun_i=-2147483648
-     defun=real(defun_i)
+     defun=-999.0
   end if
 
   do j=1,nc
@@ -941,7 +930,6 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
 !-- ʲ, 
   integer :: i, m, n, id
   integer :: nx, ny
-  integer :: defun_i
   real :: k1, k2, k3, k4, l1, l2, l3, l4
   real :: x1, y1
   real :: inter_p(2)  ! Ǥΰֺɸ󹹿
@@ -972,10 +960,8 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
 
   if(present(undef))then
      defun=undef
-     defun_i=int(undef)
   else
-     defun_i=-2147483648
-     defun=real(defun_i)
+     defun=-999.0
   end if
 
   if(present(stdopt))then
@@ -991,13 +977,13 @@ subroutine Stream_Line_2d( dt, step, ini_x, ini_y, x, y, u, v,  &
 !-- ֤
         inter_p=(/trajx(i), trajy(i)/)
 !-- ֤ζ˵ 4 ׻.
-        call interpo_search_2d( x, y, trajx(i), trajy(i), m, n, defun_i )  
+        call interpo_search_2d( x, y, trajx(i), trajy(i), m, n )  
 
 !-- ®پ줬 undef Ǥ, λǤʹߤΥǡˤ undef 
 !-- , undef ƶϰ̲ᤷݤ.
 !-- ޤ, interpo_search ˤƸΰ賰ξ⤽ʹ߷׻Բǽ
 !-- ǤݤΤ, undef  undef ʤХȴ.
-        if(m==defun_i.or.n==defun_i.or.m==nx.or.n==ny)then
+        if(m==0.or.n==0.or.m==nx.or.n==ny)then
            if(stderr.eqv..true.)then
               write(*,*) "*********** WARNING ********"
               write(*,*) "There is no parcel point in the calculating region."
@@ -1461,7 +1447,6 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
   character(3) :: option
 !-- ʲ, 
   integer :: i, l, m, n, nx, ny, nz, id
-  integer :: defun_i
   real :: k1, k2, k3, k4, l1, l2, l3, l4
   real :: x1, y1, z1, n1, n2, n3, n4
   real :: inter_p(3)  ! Ǥΰֺɸ󹹿
@@ -1494,10 +1479,8 @@ subroutine Stream_Line_3d( dt, step, ini_x, ini_y, ini_z,  &
 
   if(present(undef))then
      defun=undef
-     defun_i=int(undef)
   else
-     defun_i=-2147483648
-     defun=real(defun_i)
+     defun=-999.0
   end if
 
   if(present(stdopt))then
